<?php

/**
 * @package     Joomla.Site
 * @subpackage  Template.system
 *
 * @copyright   (C) 2005 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;

/** @var Joomla\CMS\Document\HtmlDocument $this */

$app = Factory::getApplication();
$wa  = $this->getWebAssetManager();

// Styles
$wa->registerAndUseStyle('template.system.offline', 'templates/texno/css/offline.min.css');

if ($this->direction === 'rtl') {
    $wa->registerAndUseStyle('template.system.offline_rtl', 'templates/texno/css/offline_rtl.css');
}

$wa->registerAndUseStyle('template.system.general', 'templates/texno/css/style.css');

?>
<!DOCTYPE html>
<html lang="<?php echo $this->language; ?>" dir="<?php echo $this->direction; ?>">

<head>
<link rel="alternate" hreflang="ru" href="/" />
<meta name="yandex" content="noindex, nofollow">
<meta name="googlebot" content="noindex, nofollow">
<meta name="robots" content="noindex, nofollow">
<meta name="MobileOptimized" content="320">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
<meta name="format-detection" content="telephone=no">
<meta name="format-detection" content="address=no">
<meta name="HandheldFriendly" content="True">
<meta name="MobileOptimized" content="320">
<link rel="icon" type="image/svg+xml" href="/assets/images/favicon.svg">
<link rel="icon" type="image/png" href="/assets/images/favicon.png">
    <jdoc:include type="head" />
	
	
<link onload="this.rel='stylesheet'" rel="stylesheet" href="templates/texno/css/offline.min.css" as="style" media="all" type="text/css" crossorigin="anonymous" />	
<link onload="this.rel='stylesheet'" rel="stylesheet" href="//cdn.jsdelivr.net/gh/ssergo71/site@main/bootstrap/530.1500/css/bootstrap.min.css" as="style" media="all" type="text/css" crossorigin="anonymous" />

<style>
.custom-tooltip {--bs-tooltip-bg: var(--bs-primary) !important;}
</style>

</head>

<body id="ofl">

<main>
<div class="container-fluid">
<div class="colums">
    <jdoc:include type="message" />
    <div id="frame" class="outline">
        <?php if ($app->get('offline_image') && file_exists($app->get('offline_image'))) : ?>
            <img src="<?php echo $app->get('offline_image'); ?>" alt="<?php echo htmlspecialchars($app->get('sitename'), ENT_COMPAT, 'UTF-8'); ?>" />
        <?php endif; ?>
		<div class="headtip">
		<!--<img class="lghdr" src="images/appleicon/favicon-36x36.png" alt="logo" />-->
		<img class="lghdr" src="images/appleicon/favicon.svg" alt="logo" />
        <h1>
            <?php echo htmlspecialchars($app->get('sitename'), ENT_COMPAT, 'UTF-8'); ?>
        </h1>
		</div>
    <?php if ($app->get('display_offline_message', 1) == 1 && str_replace(' ', '', $app->get('offline_message')) !== '') : ?>
        <p>
            <?php echo $app->get('offline_message'); ?>
        </p>
    <?php elseif ($app->get('display_offline_message', 1) == 2 && str_replace(' ', '', Text::_('JOFFLINE_MESSAGE')) !== '') : ?>
        <p>
            <?php echo Text::_('JOFFLINE_MESSAGE'); ?>
        </p>
    <?php endif; ?>
    <form action="<?php echo Route::_('index.php', true); ?>" method="post" id="form-login">
    <fieldset class="input">
        <p id="form-login-username">
            <label class="offlabel" for="username"><?php echo Text::_('JGLOBAL_USERNAME'); ?></label>
            <input name="username" id="username" type="text" class="inputbox" alt="<?php echo Text::_('JGLOBAL_USERNAME'); ?>" autocomplete="off" autocapitalize="none" />
        </p>
        <p id="form-login-password">
            <label class="offlabel" for="passwd"><?php echo Text::_('JGLOBAL_PASSWORD'); ?></label>
            <input type="password" name="password" class="inputbox" alt="<?php echo Text::_('JGLOBAL_PASSWORD'); ?>" id="passwd" />
        </p>
        <p id="submit-button">
            <button type="submit" name="Submit" class="button login"><?php echo Text::_('JLOGIN'); ?></button>
        </p>
        <input type="hidden" name="option" value="com_users" />
        <input type="hidden" name="task" value="user.login" />
        <input type="hidden" name="return" value="<?php echo base64_encode(Uri::base()); ?>" />
        <?php echo HTMLHelper::_('form.token'); ?>
    </fieldset>
    </form>
	<div><center><label class="dark-version"><input type="checkbox" onchange="toggledark()" id="toggledark"><span class="toggledark round"></span></center></div>
    </div>
	
</div>
</div>	
</main>


<footer>
<div class="footer">
<div class="container">
<div class="row row-cols-3">
<div class="col-20 col-md ftrr">© 2023. Все права защищены</div>
<div class="col-20 col-md ftrr">поддержка <a href="https://coteam.ru/" 
 data-bs-toggle="tooltip" data-bs-custom-class="custom-tooltip" data-bs-placement="top"
 title="Coteam +79096817666" >coteam</a></div>
<div class="col-20 col-md ftrr">Технобренд +7 (925) 333-41-52</div>
</div>
</div>
</div>
</footer>



<script rel="preload" onload="this.rel='script'" src="//cdn.jsdelivr.net/npm/jquery@3.6.1/dist/jquery.min.js" media="all" type="text/javascript" as="script" crossorigin="anonymous" ></script>


<script type="text/javascript">
if(typeof(jQuery) == "undefined"){ 
    var js = document.createElement("script");
	js.async = true;
    js.type = "text/javascript"; 
    js.src = "//cdn.jsdelivr.net/npm/jquery@3.6.1/dist/jquery.min.js"; 
    document.getElementsByTagName("head")[0].appendChild(js);    
} 
</script>

<script rel="preload" async onload="this.rel='script'" src="//cdn.jsdelivr.net/gh/ssergo71/site@latest/bootstrap/530.1500/js/bootstrap.min.js" crossorigin="anonymous" media="all" type="text/javascript" as="script" ></script>
<script rel="preload" async onload="this.rel='script'" src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>
<script rel="preload" async onload="this.rel='script'" src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js" integrity="sha384-oBqDVmMz9ATKxIep9tiCxS/Z9fNfEXiDAYTujMAeBAsjFuCZSmKbSSUnQlmh/jp3" crossorigin="anonymous"></script>

</body>


<script type="text/javascript">
function toggledark() {
    if (localStorage.getItem('theme') === 'dark') {
        localStorage.removeItem('theme');
        document.body.classList.remove("dark");
        } else {
        localStorage.setItem('theme', 'dark');
        document.body.classList.add("dark");
    }
}
if (localStorage.getItem('theme') === 'dark') {
    document.body.classList.add('dark');
    document.getElementById('toggledark').checked = true;
} else {
    document.body.classList.remove('dark');
    document.getElementById('toggledark').checked = false;
}
</script>


<script type="text/javascript">
var tooltipTriggerList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'))
var tooltipList = tooltipTriggerList.map(function (tooltipTriggerEl) {
  return new bootstrap.Tooltip(tooltipTriggerEl)
})
</script>

</html>
